@@ -1,9 +1,10 @@
+# typed: false
 # coding: utf-8
 
 describe PDF::Reader::PageLayout do
   describe "#to_s" do
     context "with an A4 page" do
-      let(:mediabox) { [0, 0, 595.28, 841.89 ]}
+      let(:mediabox) { PDF::Reader::Rectangle.new(0, 0, 595.28, 841.89)}
 
       context "with no words" do
         subject { PDF::Reader::PageLayout.new([], mediabox)}
@@ -200,6 +201,29 @@ describe PDF::Reader::PageLayout do
           expect(subject.to_s).to eq("bold")
         end
       end
+      context "with one word and the mediabox is provided as a 4-element array" do
+        let!(:runs) do
+          [
+            PDF::Reader::TextRun.new(30, 700, 50, 12, "Hello")
+          ]
+        end
+        subject { PDF::Reader::PageLayout.new(runs, mediabox.to_a)}
+
+        it "returns a correct string and prints a deprecation warning" do
+          expect(subject.to_s).to eq("Hello")
+        end
+      end
     end
+    context "with a page that's too small to fit any of the text" do
+      let(:mediabox) { PDF::Reader::Rectangle.new(0, 0, 46.560, 32.640)}
+      let(:font_size) { 72 }
+
+      it "returns an empty string" do
+        run = PDF::Reader::TextRun.new(0, 0, 50, font_size, "a")
+        layout = PDF::Reader::PageLayout.new([run], mediabox)
+        expect(layout.to_s).to eq("")
+      end
+    end
+
   end
 end
